@@ -4,8 +4,6 @@ use io::Write;
 use json;
 use std::io;
 use log;
-// use directories_next::ProjectDirs;
-// use grateful_cli::utils;
 mod utils;
 
 
@@ -124,7 +122,9 @@ fn main() -> io::Result<()> {
             } else if r.pattern == "last".to_string() {
                 let grateful: json::JsonValue = get_json();
                 let len = grateful["grateful"].len();
-                println!("{}", grateful["grateful"][len - 2].to_string());
+                if len > 0 {
+                    println!("{}", grateful["grateful"][len - 1].to_string());
+                }
             } else {
                 println!("Oops, {} is not a valid pattern.\nTry `grateful history` or `grateful last` instead", r.pattern);
             }
